//	FileLoader.h - Class to load and save the SlotValues struct.
//	----------------------------------------------------------------------------
//	This file is part of Mouse To OSC, a simple OSC-outputting program.
//	Copyright (c) 2006 Niall Moody.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//	----------------------------------------------------------------------------

#ifndef FILELOADER_H_
#define FILELOADER_H_

typedef struct sValues SlotValues;

///	Class to load and save the SlotValues struct.
class FileLoader
{
  public:
	///	Constructor.
	/*!
		\param path Path to the file to load/save.
	 */
	FileLoader(const String& path);
	///	Destructor.
	~FileLoader();

	///	Loads the SlotValues from the associated file, into slots.
	/*!
		/param slots Pointer to an array of 8 SlotValues which FileLoader will
		write to.
	 */
	void loadFile(SlotValues *slots,
				  String& ipAddress,
				  String& port,
				  int& midiInput);

	///	Saves the values in slots to the associated file.
	void saveFile(SlotValues *slots,
				  const String& ipAddress,
				  const String& port,
				  int midiInput);

    juce_UseDebuggingNewOperator
  private:
	///	Path to the file.
	String filePath;
};

#endif
