//	PadControl.cpp - Combination of widgets to send OSC messages based around an
//				     XYPad.
//	----------------------------------------------------------------------------
//	This file is part of Mouse To OSC, a simple OSC-outputting program.
//	Copyright (c) 2006 Niall Moody.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//	----------------------------------------------------------------------------

#include <juce.h>
#include "PadControl.h"
#include "XYPad.h"
#include <iostream>

using namespace std;

//------------------------------------------------------------------------------
PadControl::PadControl():
Component(),
ChangeBroadcaster()
{
	addAndMakeVisible(addressXLabel = new Label(T("aXL"), T("OSC Address X:")));
	addAndMakeVisible(addressXEditor = new TextEditor());
	addAndMakeVisible(addressYLabel = new Label(T("aYL"), T("OSC Address Y:")));
	addAndMakeVisible(addressYEditor = new TextEditor());
	addAndMakeVisible(xyPad = new XYPad());
	xyPad->addChangeListener(this);
	addAndMakeVisible(yMax = new TextEditor());
	yMax->setText(T("1.0"));
	addAndMakeVisible(yMin = new TextEditor());
	yMin->setText(T("0.0"));
	addAndMakeVisible(xMin = new TextEditor());
	xMin->setText(T("0.0"));
	addAndMakeVisible(xMax = new TextEditor());
	xMax->setText(T("1.0"));
	addAndMakeVisible(xCc = new TextEditor());
	xCc->setText(T("<CC>"));
	addAndMakeVisible(yCc = new TextEditor());
	yCc->setText(T("<CC>"));
}

//------------------------------------------------------------------------------
PadControl::~PadControl()
{
	deleteAllChildren();
}

//------------------------------------------------------------------------------
void PadControl::resized()
{
	addressXLabel->setBounds(2, 2, 100, 22);
	addressXEditor->setBounds(104, 2, (getWidth()-106), 22);
	addressYLabel->setBounds(2, 28, 100, 22);
	addressYEditor->setBounds(104, 28, (getWidth()-106), 22);
	xyPad->setBounds(54, 54, (getWidth()-56), (getWidth()-56));
	yMax->setBounds(10, 54, 40, 22);
	yMin->setBounds(10, ((getWidth()-56)+30), 40, 22);
	xMin->setBounds(54, ((getWidth()-54)+58), 40, 22);
	xMax->setBounds((getWidth()-42), ((getWidth()-54)+58), 40, 22);
	yCc->setBounds(0, ((getWidth()-56)/2)+40, 50, 22);
	xCc->setBounds(((getWidth()-42)/2)+22, ((getWidth()-54)+58), 50, 22);
}

//------------------------------------------------------------------------------
void PadControl::changeListenerCallback(void *objectThatHasChanged)
{
	if(objectThatHasChanged == xyPad)
		sendChangeMessage(this);
}

//------------------------------------------------------------------------------
float PadControl::getXVal() const
{
	float tempMin, tempMax;
	float tempf;

	tempMin = xMin->getText().getFloatValue();
	tempMax = xMax->getText().getFloatValue();

	tempf = tempMax - tempMin;

	tempf *= xyPad->getXVal();

	if(tempMin < tempMax)
		tempf += tempMin;
	else
		tempf += tempMax;

	return tempf;
}

//------------------------------------------------------------------------------
float PadControl::getYVal() const
{
	float tempMin, tempMax;
	float tempf;

	tempMin = yMin->getText().getFloatValue();
	tempMax = yMax->getText().getFloatValue();

	tempf = tempMax - tempMin;

	tempf *= xyPad->getYVal();

	if(tempMin < tempMax)
		tempf += tempMin;
	else
		tempf += tempMax;

	return tempf;
}

//------------------------------------------------------------------------------
void PadControl::setXAddress(const String& val)
{
	addressXEditor->setText(val);
}

//------------------------------------------------------------------------------
void PadControl::setYAddress(const String& val)
{
	addressYEditor->setText(val);
}

//------------------------------------------------------------------------------
void PadControl::setYMax(const String& val)
{
	yMax->setText(val);
}

//------------------------------------------------------------------------------
void PadControl::setYMin(const String& val)
{
	yMin->setText(val);
}

//------------------------------------------------------------------------------
void PadControl::setXMax(const String& val)
{
	xMax->setText(val);
}

//------------------------------------------------------------------------------
void PadControl::setXMin(const String& val)
{
	xMin->setText(val);
}

//------------------------------------------------------------------------------
void PadControl::setXVal(float val)
{
	float tempMin, tempMax;
	float tempf = val;

	tempMin = xMin->getText().getFloatValue();
	tempMax = xMax->getText().getFloatValue();

	if(tempMin < tempMax)
	{
		tempf -= tempMin;
		tempf /= fabs(tempMax - tempMin);
	}
	else
	{
		tempf -= tempMax;
		tempf /= fabs(tempMin - tempMax);
	}

	xyPad->setXVal(tempf);
}

//------------------------------------------------------------------------------
void PadControl::setYVal(float val)
{
	float tempMin, tempMax;
	float tempf = val;

	tempMin = yMin->getText().getFloatValue();
	tempMax = yMax->getText().getFloatValue();

	if(tempMin < tempMax)
	{
		tempf -= tempMin;
		tempf /= fabs(tempMax - tempMin);
	}
	else
	{
		tempf -= tempMax;
		tempf /= fabs(tempMin - tempMax);
	}

	xyPad->setYVal(tempf);
}

//------------------------------------------------------------------------------
void PadControl::setXCc(const String& val)
{
	xCc->setText(val);
}

//------------------------------------------------------------------------------
void PadControl::setYCc(const String& val)
{
	yCc->setText(val);
}

//------------------------------------------------------------------------------
void PadControl::setXValNorm(float val)
{
	xyPad->setXVal(val);
	sendChangeMessage(this);
}

//------------------------------------------------------------------------------
void PadControl::setYValNorm(float val)
{
	xyPad->setYVal(val);
	sendChangeMessage(this);
}
