//	StandardPhilToolbar.cpp - Standard toolbar Component for Phil.
//	--------------------------------------------------------------------------
//	This file is part of 'Phil', a very simple file manager/browser for the
//	JUCE library.
//	Copyright (C) 2005-2006  Niall Moody
//	
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//	
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//	
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//	
//	--------------------------------------------------------------------------

#include <juce.h>
#include "StandardPhilToolbar.h"
#include "PhilComponent.h"

//----------------------------------------------------------------------------
StandardPhilToolbar::StandardPhilToolbar(Phil *parentComponent):
Component(),
parent(parentComponent)
{
	DrawablePath drawable;
	Path patty;

	addAndMakeVisible(backButton = new DrawableButton(T("Back"),
													  DrawableButton::ImageOnButtonBackground));
	patty.addArrow(26.0f,
				   12.0f,
				   2.0f,
				   12.0f,
				   8.0f,
				   20.0f,
				   12.0f);
	drawable.setPath(patty);
	drawable.setSolidFill(Colours::white);
	backButton->setImages(&drawable);
	/*backButton->setBackgroundColours(Colours::palegreen.darker(0.2f).withSaturation(0.1f),
									 Colours::darkgreen);*/
	backButton->setBackgroundColours(Colours::palegreen.darker(0.25f), Colours::darkgreen);
	backButton->addButtonListener(this);

	addAndMakeVisible(forwardButton = new DrawableButton(T("Forward"),
														 DrawableButton::ImageOnButtonBackground));
	patty.clear();
	patty.addArrow(2.0f,
				   12.0f,
				   26.0f,
				   12.0f,
				   8.0f,
				   20.0f,
				   12.0f);
	drawable.setPath(patty);
	drawable.setSolidFill(Colours::white);
	forwardButton->setImages(&drawable);
	/*forwardButton->setBackgroundColours(Colours::palegreen.darker(0.2f).withSaturation(0.1f),
										Colours::darkgreen);*/
	forwardButton->setBackgroundColours(Colours::palegreen.darker(0.25f), Colours::darkgreen);
	forwardButton->addButtonListener(this);

	addAndMakeVisible(upButton = new DrawableButton(T("Up"),
													DrawableButton::ImageOnButtonBackground));
	patty.clear();
	patty.addArrow(12.0f,
				   26.0f,
				   12.0f,
				   2.0f,
				   8.0f,
				   20.0f,
				   12.0f);
	drawable.setPath(patty);
	drawable.setSolidFill(Colours::white);
	upButton->setImages(&drawable);
	/*upButton->setBackgroundColours(Colours::lightblue.withBrightness(0.925f),
								   Colours::darkblue);*/
	upButton->setBackgroundColours(Colours::lightblue.darker(0.1f), Colours::darkblue);
	upButton->addButtonListener(this);

	addAndMakeVisible(homeButton = new DrawableButton(T("Home"),
													  DrawableButton::ImageOnButtonBackground));
	patty.clear();
	patty.addArrow(12.0f,
				   26.0f,
				   12.0f,
				   2.0f,
				   20.0f,
				   28.0f,
				   12.0f);
	patty.addRectangle(2.5f, 2.0f, 4.0f, 10.0f);
	drawable.setPath(patty);
	drawable.setSolidFill(Colours::white);
	homeButton->setImages(&drawable);
	//homeButton->setBackgroundColours(Colours::lightpink, Colours::yellow);
	homeButton->setBackgroundColours(Colours::red, Colours::yellow);
	homeButton->addButtonListener(this);

	parent->addChangeListener(this);

	currentDirectory = parent->getCurrentDirectory().getFullPathName();
}

//----------------------------------------------------------------------------
StandardPhilToolbar::~StandardPhilToolbar()
{
	deleteAllChildren();

	while(!backHistory.empty())
	{
		delete (backHistory.top());
		backHistory.pop();
	}
	while(!forwardHistory.empty())
	{
		delete (forwardHistory.top());
		forwardHistory.pop();
	}
}

//----------------------------------------------------------------------------
void StandardPhilToolbar::resized()
{
	backButton->setBounds(2, 2, 28, 28);
	forwardButton->setBounds(32, 2, 28, 28);
	upButton->setBounds(62, 2, 28, 28);
	homeButton->setBounds(102, 2, 28, 28);
}

//----------------------------------------------------------------------------
void StandardPhilToolbar::changeListenerCallback(void *objectThatHasChanged)
{
	//Update history.
	//We will only get here if the user double-clicks a directory in FileView,
	//so we know a forward action has not taken place.
	//Because we know this, we also know that the forwardHistory should now
	//be cleared, so the user doesn't get confused.
	if(objectThatHasChanged == parent)
	{
		if(parent->getCurrentDirectory().getFullPathName() != currentDirectory)
		{
			String *tempstr = new String(currentDirectory);
			backHistory.push(tempstr);
			currentDirectory = parent->getCurrentDirectory().getFullPathName();
			while(!forwardHistory.empty())
			{
				delete forwardHistory.top();
				forwardHistory.pop();
			}
		}
	}
}

//----------------------------------------------------------------------------
void StandardPhilToolbar::buttonClicked(Button *button)
{
	if(button == upButton)
		parent->navToParent();
		//parent->setCurrentDirectory(parent->getCurrentDirectory().getParentDirectory());
	else if(button == backButton)
	{
		if(!backHistory.empty())
		{
			forwardHistory.push(new String (currentDirectory));
			currentDirectory = *(backHistory.top());
			delete (backHistory.top());
			backHistory.pop();

			parent->setCurrentDirectory(File(currentDirectory), false);
		}
	}
	else if(button == forwardButton)
	{
		if(!forwardHistory.empty())
		{
			backHistory.push(new String(currentDirectory));
			currentDirectory = *(forwardHistory.top());
			delete (forwardHistory.top());
			forwardHistory.pop();

			parent->setCurrentDirectory(File(currentDirectory), false);
		}
	}
	else if(button == homeButton)
		parent->setCurrentDirectory(SystemStats::getUserHomeDirectory());
}
