//	SliderControl.cpp - Combination of widgets to send OSC messages based around
//						a slider.
//	----------------------------------------------------------------------------
//	This file is part of Mouse To OSC, a simple OSC-outputting program.
//	Copyright (c) 2006 Niall Moody.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//	----------------------------------------------------------------------------

#include <juce.h>
#include "SliderControl.h"

//------------------------------------------------------------------------------
SliderControl::SliderControl():
Component(),
ChangeBroadcaster()
{
	addAndMakeVisible(addressLabel = new Label(T("aL"), T("OSC Address:")));
	addAndMakeVisible(addressEditor = new TextEditor());
	addAndMakeVisible(sliderControl = new Slider(T("sC")));
	sliderControl->setSliderStyle(Slider::LinearHorizontal);
	sliderControl->setRange(0.0f, 1.0f);
	sliderControl->setTextBoxStyle(Slider::NoTextBox, true, 0, 0);
	sliderControl->setDoubleClickReturnValue(true, 0.5f);
	sliderControl->addListener(this);
	addAndMakeVisible(sliderMin = new TextEditor());
	sliderMin->setText(T("0.0"));
	addAndMakeVisible(sliderMax = new TextEditor());
	sliderMax->setText(T("1.0"));
	addAndMakeVisible(ccEditor = new TextEditor());
	ccEditor->setText(T("<MIDI CC>"));
}

//------------------------------------------------------------------------------
SliderControl::~SliderControl()
{
	deleteAllChildren();
}

//------------------------------------------------------------------------------
void SliderControl::resized()
{
	addressLabel->setBounds(2, 2, 90, 22);
	addressEditor->setBounds(94, 2, (getWidth()-96), 22);
	sliderControl->setBounds(2, 26, (getWidth()-4), 22);
	sliderMin->setBounds(2, 50, 40, 22);
	sliderMax->setBounds((getWidth()-42), 50, 40, 22);
	ccEditor->setBounds((getWidth()/2)-41, 50, 82, 22);
}

//------------------------------------------------------------------------------
void SliderControl::sliderValueChanged(Slider *slider)
{
	sendChangeMessage(this);
}

//------------------------------------------------------------------------------
float SliderControl::getSliderVal() const
{
	float tempMin, tempMax;
	float tempf;

	tempMin = sliderMin->getText().getFloatValue();
	tempMax = sliderMax->getText().getFloatValue();

	tempf = tempMax - tempMin;

	tempf *= sliderControl->getValue();

	if(tempMin < tempMax)
		tempf += tempMin;
	else
		tempf += tempMax;

	return tempf;
}

//------------------------------------------------------------------------------
void SliderControl::setAddress(const String& val)
{
	addressEditor->setText(val);
}

//------------------------------------------------------------------------------
void SliderControl::setMax(const String& val)
{
	sliderMax->setText(val);
}

//------------------------------------------------------------------------------
void SliderControl::setMin(const String& val)
{
	sliderMin->setText(val);
}

//------------------------------------------------------------------------------
void SliderControl::setValue(float val)
{
	sliderControl->setValue(val);
}

//------------------------------------------------------------------------------
void SliderControl::setCc(const String& val)
{
	ccEditor->setText(val);
}

//------------------------------------------------------------------------------
void SliderControl::setValueNorm(float val)
{
	sliderControl->setValue(val);
	sendChangeMessage(this);
}
